@@ -65,8 +65,7 @@ def sendRequests(funcName, *args):
         data_bin = cloudpickle.dumps(thisArg)
         serializedObj = str(base64.b64encode(data_bin), "utf-8")
         argsSerialized.append(serializedObj)
-    
-    json_data['userId'] = 'POD_APP_'+str(base64.b64encode(str(USER_ID).encode()), 'utf-8')
+    json_data['userId'] = 'EXT_API'+str(base64.b64encode(str(USER_ID).encode()), 'utf-8')
     json_data['funcName'] = funcName
     json_data['args'] = argsSerialized
     newJson['jsonData'] = json.dumps(json_data)
@@ -74,6 +73,9 @@ def sendRequests(funcName, *args):
     res = requests.post(thisUrl, data=newJsonB, verify=False)
     resJson = json.loads(res.text)
     if int(resJson['res']) == 1:
+        if len(resJson['resPrintArr']) > 0:
+            for thisMsg in resJson['resPrintArr']:
+                print(thisMsg)
         return cloudpickle.loads(base64.b64decode(resJson['serializedObj']))
     else:
         print("Could not proceed the request")
@@ -83,9 +85,13 @@ def getDataDB():
     funcName = str(inspect.stack()[0][0].f_code.co_name)
     return sendRequests(funcName)
 
-def getData(thisData):
+def getData(apiId, dispoDate=None):
     funcName = str(inspect.stack()[0][0].f_code.co_name)
-    return sendRequests(funcName, thisData)
+    return sendRequests(funcName, apiId, dispoDate)
+
+def getDispoDates(apiId):
+    funcName = str(inspect.stack()[0][0].f_code.co_name)
+    return sendRequests(funcName, apiId)
 
 def getDataDates(thisDates, formula, bBusiness=True, formatDate='%Y%m%d'):
     funcName = str(inspect.stack()[0][0].f_code.co_name)
@@ -111,13 +117,24 @@ def getYTD(thisDate=None, formatDate='%Y%m%d'):
     funcName = str(inspect.stack()[0][0].f_code.co_name)
     return sendRequests(funcName, thisDate, formatDate)
 
+def putData(dataObj, name, apiId=None, dateDispo=None):
+    funcName = str(inspect.stack()[0][0].f_code.co_name)
+    return sendRequests(funcName, dataObj, name, apiId, dateDispo)
+
 def putExec(str2Eval, name):
     funcName = str(inspect.stack()[0][0].f_code.co_name)
     return sendRequests(funcName, str2Eval, name)
 
-def runFunction(functionName, *args):
+def getUUID():
+    '''
+        Get My UUID
+    '''
     funcName = str(inspect.stack()[0][0].f_code.co_name)
-    return sendRequests(funcName, functionName, *args)
+    return sendRequests(funcName)
+
+def runFunction(apiId, *args):
+    funcName = str(inspect.stack()[0][0].f_code.co_name)
+    return sendRequests(funcName, apiId, *args)
 
 def createFunction(functionObj):
     functionSource = inspect.getsource(functionObj)
@@ -187,5 +204,4 @@ if not bInternalJupyterDesktop:
             printError()
     except:
         printError()
-
 # **********************************************************************************************************************
\ No newline at end of file
